==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/PortSelectorBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PortSelectorBuilder extends PortSelectorFluentImpl<PortSelectorBuilder> implements VisitableBuilder<PortSelector,PortSelectorBuilder>{
  public PortSelectorBuilder() {
    this(false);
  }
  public PortSelectorBuilder(Boolean validationEnabled) {
    this(new PortSelector(), validationEnabled);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PortSelector(), validationEnabled);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent,PortSelector instance) {
    this(fluent, instance, false);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent,PortSelector instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withNumber(instance.getNumber());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PortSelectorBuilder(PortSelector instance) {
    this(instance,false);
  }
  public PortSelectorBuilder(PortSelector instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withNumber(instance.getNumber());
    }
    this.validationEnabled = validationEnabled; 
  }
  PortSelectorFluent<?> fluent;
  Boolean validationEnabled;
  public PortSelector build() {
    PortSelector buildable = new PortSelector(fluent.getNumber());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/PortSelectorBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PortSelectorBuilder extends PortSelectorFluent<PortSelectorBuilder> implements VisitableBuilder<PortSelector,PortSelectorBuilder>{
  public PortSelectorBuilder() {
    this(false);
  }
  public PortSelectorBuilder(Boolean validationEnabled) {
    this(new PortSelector(), validationEnabled);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PortSelector(), validationEnabled);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent,PortSelector instance) {
    this(fluent, instance, false);
  }
  public PortSelectorBuilder(PortSelectorFluent<?> fluent,PortSelector instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PortSelector());

    if (instance != null) {
      fluent.withNumber(instance.getNumber());
      fluent.withNumber(instance.getNumber());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PortSelectorBuilder(PortSelector instance) {
    this(instance,false);
  }
  public PortSelectorBuilder(PortSelector instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PortSelector());

    if (instance != null) {
      this.withNumber(instance.getNumber());
      this.withNumber(instance.getNumber());
    }
    this.validationEnabled = validationEnabled; 
  }
  PortSelectorFluent<?> fluent;
  Boolean validationEnabled;
  public PortSelector build() {
    PortSelector buildable = new PortSelector(fluent.getNumber());
    return buildable;
  }
  
}
